@@ -20,7 +20,7 @@ except ImportError:
     PLOTTING = False
 
 
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 """
 Copyright 2018, Alexander J. Tarashansky, All rights reserved.
@@ -482,6 +482,8 @@ class SAM(object):
         
         D_avg = ((nnm/self.k).dot(self.D))
         
+        self.D_avg = D_avg.copy()
+
         mu = D_avg.mean(0)
         Ex2=np.square(mu) 
         D_avg.data=D_avg.data**2
@@ -498,8 +500,6 @@ class SAM(object):
 
         indices = np.argsort(-weights)
         
-        self.D_avg = D_avg
-
         return indices, weights
 
     def run(self,
